@@ -3,6 +3,9 @@
 # Univention Samba
 #  listener module: manages samba share configuration
 #
+# Like what you see? Join us!
+# https://www.univention.com/about-us/careers/vacancies/
+#
 # Copyright 2001-2022 Univention GmbH
 #
 # https://www.univention.de/
@@ -110,11 +113,11 @@ def handler(dn, new, old, command):
 		try:
 			# object was renamed -> save old object
 			if command == "r" and old:
-				with open(tmpFile, "w+") as fd:
+				with open(tmpFile, "wb+") as fd:
 					os.chmod(tmpFile, 0o600)
 					pickle.dump({"dn": dn, "old": old}, fd)
 			elif command == "a" and not old and os.path.isfile(tmpFile):
-				with open(tmpFile, "r") as fd:
+				with open(tmpFile, "rb") as fd:
 					p = pickle.load(fd)
 				oldObject = p.get("old", {})
 				os.remove(tmpFile)
